<?php

/**
 * @file
 * Admin page callback file for the og teams module.
 */

/**
 * Menu callback: administer og teams.
 *
 * @see user_admin_team_validate()
 * @see user_admin_team_submit()
 * @see theme_user_admin_new_team()
 */
function og_teams_admin_team() {
  $tid = arg(4);
  if ($tid) {
    // Display the edit group form.
    $team = db_fetch_object(db_query('SELECT * FROM {og_teams} WHERE tid = %d', $tid));
    if (!$team) {
      drupal_goto('admin/og/og_teams');
    }
    $form['name'] = array(
      '#type' => 'textfield',
      '#title' => t('Team name'),
      '#default_value' => $team->name,
      '#size' => 64,
      '#required' => TRUE,
      '#maxlength' => 255,
      '#description' => t('The name for this team. Example: "group moderators", "quality assurance", "administrators".'),
    );
    $form['tid'] = array(
      '#type' => 'value',
      '#value' => $tid,
    );
    $form['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Save team'),
    );
    $form['delete'] = array(
      '#type' => 'submit',
      '#value' => t('Delete team'),
    );
  }
  else {
    $form['name'] = array(
      '#type' => 'textfield',
      '#size' => 64,
      '#maxlength' => 255,
    );
    $form['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Add team'),
    );
    $form['#submit'][] = 'og_teams_admin_team_submit';
    $form['#validate'][] = 'og_teams_admin_team_validate';
  }
  return $form;
}

/**
 *
 */
function og_teams_admin_team_validate($form, &$form_state) {
  if ($form_state['values']['name']) {
    if ($form_state['values']['op'] == t('Save team')) {
      if (db_result(db_query("SELECT COUNT(*) FROM {og_teams} WHERE name = '%s' AND tid != %d", $form_state['values']['name'], $form_state['values']['tid']))) {
        form_set_error('name', t('The team name %name already exists. Please choose another team name.', array('%name' => $form_state['values']['name'])));
      }
    }
    else if ($form_state['values']['op'] == t('Add team')) {
      if (db_result(db_query("SELECT COUNT(*) FROM {og_teams} WHERE name = '%s'", $form_state['values']['name']))) {
        form_set_error('name', t('The team name %name already exists. Please choose another team name.', array('%name' => $form_state['values']['name'])));
      }
    }
  }
  else {
    form_set_error('name', t('You must specify a valid team name.'));
  }
}

/**
 *
 */
function og_teams_admin_team_submit($form, &$form_state) {
  if ($form_state['values']['op'] == t('Save team')) {
    db_query("UPDATE {og_teams} SET name = '%s' WHERE tid = %d", $form_state['values']['name'], $form_state['values']['tid']);
    drupal_set_message(t('The team has been saved.'));
  }
  else if ($form_state['values']['op'] == t('Delete team')) {
    $destination = '';
    if (isset($_REQUEST['destination'])) {
      $destination = drupal_get_destination();
      unset($_REQUEST['destination']);
    }
    $form_state['redirect'] = array('admin/og/og_teams/delete/'. $form_state['values']['tid'], $destination);
    return;
  }
  else if ($form_state['values']['op'] == t('Add team')) {
    db_query("INSERT INTO {og_teams} (name) VALUES ('%s')", $form_state['values']['name']);
    drupal_set_message(t('The team has been added.'));
  }
  $form_state['redirect'] = 'admin/og/og_teams';
}

/**
 * Team delete page.
 */
function og_teams_admin_delete(&$form_state, $tid) {
  $team = db_fetch_object(db_query('SELECT * FROM {og_teams} WHERE tid = %d', $tid));
  if (!$team) {
    drupal_goto('admin/og/og_teams');
  }
  $form['team'] = array(
    '#type' => 'value',
    '#value' => $team,
  );
  return confirm_form($form, t('Are you sure you want to delete the team %team?', array('%team' => $team->name)), 'admin/og/og_teams', t('This action cannot be undone.'), t('Delete'), t('Cancel'));
}

/**
 * Process team delete form submission.
 */
function og_teams_admin_delete_submit($form, &$form_state) {
  $team = $form_state['values']['team'];

  // @todo Unsubscribe users from groups
  db_query('DELETE FROM {og_teams} WHERE tid = %d', $team->tid);
  db_query('DELETE FROM {og_teams_users} WHERE tid = %d', $team->tid);
  db_query('DELETE FROM {og_teams_groups} WHERE tid = %d', $team->tid);

  drupal_set_message(t('The team %team has been deleted.', array('%team' => $team->name)));
  //watchdog('og_teams', 'Contact form: category %category deleted.', array('%category' => $contact['category']), WATCHDOG_NOTICE);

  $form_state['redirect'] = 'admin/og/og_teams';
}

/**
 * Menu callback: manager users teams.
 */
function og_teams_admin_users_team() {
  $tid = arg(4);
  $team = db_fetch_object(db_query('SELECT * FROM {og_teams} WHERE tid = %d', $tid));
  if (!$team) {
    drupal_goto('admin/og/og_teams');
  }
  drupal_set_title(t('Manage users of the team %team', array('%team' => $team->name)));

  $form['og_teams_names'] = array(
    '#type' => 'textarea',
    '#title' => t('List of users'),
    '#rows' => 5,
    '#cols' => 70,
    '#description' => t('Add one or more usernames in order to associate users with this team. Multiple usernames should be separated by a comma.'),
    '#element_validate' => array('og_teams_admin_users_team_validate'),
  );
  $form['op'] = array('#type' => 'submit', '#value' => t('Add users'));
  $form['tid'] = array('#type' => 'value', '#value' => $team->tid);

  return $form;
}

/**
 *
 */
function og_teams_admin_users_team_submit($form, &$form_state) {
  // Safest option is to do a select, filter existing members, then insert.
  $names = explode(',', $form_state['values']['og_teams_names']);
  $accounts = array();
  foreach ($names as $name) {
    $account = user_load(array('name' => trim($name)));
    if ($account->uid) {
      $accounts[] = $account;
    }
  }
  foreach ($accounts as $account) {
    og_teams_team_user_add($form_state['values']['tid'], $account->uid);
  }
  drupal_set_message(format_plural(count($accounts), '1 user added to the team.', '@count users added to the team.'));
}

/**
 * Confirm team unsubscription form.
 */
function og_teams_admin_confirm_unsubscribe_team($form_state, $tid, $account) {
  $team = db_fetch_object(db_query('SELECT * FROM {og_teams} WHERE tid = %d', $tid));
  if (!$team) {
    drupal_goto('admin/og/og_teams');
  }
  $form['team'] = array('#type' => 'value', '#value' => $team);
  $form['account'] = array('#type' => 'value', '#value' => $account);
  $message = t('Are you sure you want to remove !name from the team %title?', array('!name' => theme('username', $account), '%title' => $team->name));
  return confirm_form($form, $message, 'admin/og/og_teams/users/'. $team->tid, ' ', t('Remove'), t('Cancel'));
}

/**
 * Confirm team unsubscription submit handler.
 */
function og_teams_admin_confirm_unsubscribe_team_submit($form, &$form_state) {
  $team = $form_state['values']['team'];
  $account = $form_state['values']['account'];
  og_teams_team_user_delete($team->tid, $account->uid);
  drupal_set_message(t('%user removed from the team %team.', array('%user' => $account->name, '%team' => $team->name)));
  $form_state['redirect'] = 'admin/og/og_teams/users/'. $team->tid;
}

/**
 * Form builder for administrative settings.
 */
function og_teams_admin_settings() {
  $form['og_teams_profile'] = array(
    '#type' => 'fieldset',
    '#title' => t('User profile'),
  );
  $form['og_teams_profile']['og_teams_user_profile'] = array(
    '#type' => 'radios',
    '#title' => t('Assign teams'),
    '#options' => array(0 => t('No'), 1 => t('Yes')),
    '#default_value' => variable_get('og_teams_user_profile', 1),
    '#description' => t('Allow to admins to assign teams in user profile pages.'),
  );
  $form['og_teams_profile']['og_teams_show_user_profile'] = array(
    '#type' => 'radios',
    '#title' => t('Show list of teams'),
    '#options' => array(0 => t('No'), 1 => t('Yes')),
    '#default_value' => variable_get('og_teams_show_user_profile', 1),
    '#description' => t('Show list of teams to self and admins in user profile pages.'),
  );
  return system_settings_form($form);
}

/**
 * Theme the new-team form.
 */
function theme_og_teams_admin_new_team($form) {
  $header = array(t('Name'), array('data' => t('Operations'), 'colspan' => 2));
  if ($teams = og_teams_teams()) {
    foreach ($teams as $tid => $name) {
      $manage_users = l(t('manage users'), 'admin/og/og_teams/users/'. $tid);
      // theme('username', $account)
      $rows[] = array(check_plain($name), l(t('edit team'), 'admin/og/og_teams/edit/'. $tid), $manage_users);
    }
  }
  $rows[] = array(drupal_render($form['name']), array('data' => drupal_render($form['submit']), 'colspan' => 2));

  $output = drupal_render($form);
  $output .= theme('table', $header, $rows);

  return $output;
}

/**
 * Theme the manage users team form.
 */
function theme_og_teams_admin_users_team($form) {
  $tid = $form['tid']['#value'];
  $header = array(t('Name'), array('data' => t('Operations')/*, 'colspan' => 2*/));

  $accounts = array();
  $result = db_query('SELECT uid FROM {og_teams_users} WHERE tid = %d', $tid);
  while ($user = db_fetch_object($result)) {
    $account = user_load(array('uid' => $user->uid));
    if ($account) {
      $accounts[$user->uid] = $account;
    }
  }

  foreach ($accounts as $uid => $account) {
    $rows[] = array(l(check_plain($account->name), 'user/'. $uid), l(t('remove membership'), 'admin/og/og_teams/users/'. $tid .'/unsubscribe/'. $account->uid));
  }

  if (empty($accounts)) {
    $rows[] = array(array('data' => '<em>'. t('No associated users were found. Users can be associate to this team using the form below.') .'</em>', 'colspan' => 2));
  }

  $output = '';
  $output .= theme('table', $header, $rows);
  $output .= drupal_render($form);

  return $output;
}
