<?php

/**
 * Implementation of hook_views_handlers().
 */
function og_teams_views_handlers() {
  return array(
    'info' => array(
      'path' => drupal_get_path('module', 'og_teams') .'/views',
    ),
    'handlers' => array(
      // filters
      'og_teams_views_handler_filter_teams' => array(
        'parent' => 'views_handler_filter_many_to_one',
      ),
      // fields
      'og_teams_views_handler_field_user_teams' => array(
        'parent' => 'views_handler_field_prerender_list',
      ),
      'og_teams_views_handler_field_group_teams' => array(
        'parent' => 'views_handler_field_prerender_list',
      ),
      // arguments
      'og_teams_views_handler_argument_teams_tid' => array(
        'parent' => 'views_handler_argument_many_to_one',
      ),
    ),
  );
}

/**
 * Implementation of hook_views_data().
 */
function og_teams_views_data() {
  $data = array();

  // ----------------------------------------------------------------------
  // og_teams_users table

  $data['og_teams_users']['table']['group'] = t('User');

  // Explain how this table joins to others.
  $data['og_teams_users']['table']['join'] = array(
     // Directly links to users table.
    'users' => array(
      'left_field' => 'uid',
      'field' => 'uid',
    ),
  );

  $data['og_teams_users']['tid'] = array(
    'title' => t('Teams'),
    'help' => t('Teams that a user belongs to.'),
    'field' => array(
      'handler' => 'og_teams_views_handler_field_user_teams',
    ),
    'filter' => array(
      'handler' => 'og_teams_views_handler_filter_teams',
      'numeric' => TRUE,
    ),
    'argument' => array(
      'handler' => 'og_teams_views_handler_argument_teams_tid',
      'name table' => 'og_teams',
      'name field' => 'name',
      'empty field name' => t('No team'),
      'numeric' => TRUE,
    ),
  );

  // ----------------------------------------------------------------------
  // og_teams_groups table

  $data['og_teams_groups']['table']['group'] = t('Organic groups');

  // Explain how this table joins to others.
  $data['og_teams_groups']['table']['join'] = array(
     // Directly links to node table.
    'node' => array(
      'left_field' => 'nid',
      'field' => 'gid',
    ),
    'node_revisions' => array(
      'left_field' => 'nid',
      'field' => 'gid',
    ),
  );

  $data['og_teams_groups']['tid'] = array(
    'title' => t('Group: Teams'),
    'help' => t('Teams asociados a un grupo.'),
    'field' => array(
      'handler' => 'og_teams_views_handler_field_group_teams',
    ),
    'filter' => array(
      'handler' => 'og_teams_views_handler_filter_teams',
      'numeric' => TRUE,
    ),
    'argument' => array(
      'handler' => 'og_teams_views_handler_argument_teams_tid',
      'name table' => 'og_teams',
      'name field' => 'name',
      'empty field name' => t('No team'),
      'numeric' => TRUE,
    ),
  );

  // ----------------------------------------------------------------------
  // og_teams table

  $data['og_teams']['table']['join'] = array(
     // Directly links to users table.
    'users' => array(
      'left_table' => 'og_teams_users',
      'left_field' => 'tid',
      'field' => 'tid',
    ),
    // needed for many to one helper sometimes
    'og_teams_users' => array(
      'left_field' => 'tid',
      'field' => 'tid',
    ),
    'og_teams_groups' => array(
      'left_field' => 'tid',
      'field' => 'tid',
    ),
  );

  return $data;
}
